@@ -1,7 +1,7 @@
-#import pyautogui
+import pyautogui
 import time
 
-"""
+
 def get_mouse_pos():
   pos = pyautogui.position()
   return (pos.x, pos.y)
@@ -9,4 +9,7 @@ def get_mouse_pos():
 if __name__ == "__main__":
   print (get_mouse_pos())
 
-"""
\ No newline at end of file
+"""
+
+
+if __name__ == "__main__":
\ No newline at end of file
